summaryrefslogtreecommitdiff
path: root/nuttx/include/sys/select.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-12-14 15:46:55 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-12-14 15:46:55 +0000
commit24bdea23f746984480bd59dd13dd4d631a210320 (patch)
tree66cd9e753d9cf77ec35b1b06be757025188cefab /nuttx/include/sys/select.h
parenta23845ccf98018e8fc455677579fca2a947e1074 (diff)
downloadpx4-nuttx-24bdea23f746984480bd59dd13dd4d631a210320.tar.gz
px4-nuttx-24bdea23f746984480bd59dd13dd4d631a210320.tar.bz2
px4-nuttx-24bdea23f746984480bd59dd13dd4d631a210320.zip
Changing NuttX fixed size type names to C99 standard names -- things will be broken for awhile
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@2335 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include/sys/select.h')
-rw-r--r--nuttx/include/sys/select.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/nuttx/include/sys/select.h b/nuttx/include/sys/select.h
index a665a5882..a38bb2b77 100644
--- a/nuttx/include/sys/select.h
+++ b/nuttx/include/sys/select.h
@@ -41,6 +41,7 @@
****************************************************************************/
#include <nuttx/config.h>
+#include <stdint.h>
#include <time.h>
#if CONFIG_NFILE_DESCRIPTORS > 0 || CONFIG_NSOCKET_DESCRIPTORS > 0
@@ -54,7 +55,7 @@
#define __SELECT_NDESCRIPTORS (CONFIG_NFILE_DESCRIPTORS + CONFIG_NSOCKET_DESCRIPTORS)
/* We will use a 32-bit bitsets to represent the set of descriptors. How
* many uint32's do we need to span all descriptors?
*/
#if __SELECT_NDESCRIPTORS <= 32
@@ -84,16 +85,16 @@
/* Standard helper macros */
-#define FD_CLR(fd,set) (((uint32*)(set))[_FD_NDX(fd)] &= ~(1 << _FD_BIT(fd)))
-#define FD_SET(fd,set) (((uint32*)(set))[_FD_NDX(fd)] |= (1 << _FD_BIT(fd)))
-#define FD_ISSET(fd,set) ((((uint32*)(set))[_FD_NDX(fd)] & (1 << _FD_BIT(fd))) != 0)
+#define FD_CLR(fd,set) (((uint32_t*)(set))[_FD_NDX(fd)] &= ~(1 << _FD_BIT(fd)))
+#define FD_SET(fd,set) (((uint32_t*)(set))[_FD_NDX(fd)] |= (1 << _FD_BIT(fd)))
+#define FD_ISSET(fd,set) ((((uint32_t*)(set))[_FD_NDX(fd)] & (1 << _FD_BIT(fd))) != 0)
#define FD_ZERO(set) memset(set, 0, sizeof(fd_set))
/****************************************************************************
* Type Definitions
****************************************************************************/
-typedef uint32 fd_set[__SELECT_NUINT32];
+typedef uint32_t fd_set[__SELECT_NUINT32];
/****************************************************************************
* Public Function Prototypes
@@ -54,7 +55,7 @@
#define __SELECT_NDESCRIPTORS (CONFIG_NFILE_DESCRIPTORS + CONFIG_NSOCKET_DESCRIPTORS)
/* We will use a 32-bit bitsets to represent the set of descriptors. How
- * many uint32's do we need to span all descriptors?
+ * many uint32_t's do we need to span all descriptors?
*/
#if __SELECT_NDESCRIPTORS <= 32